# Implemented Grammar in GlyLES

## Implemented Modifications

* Sulfur-groups
  * i.e. Gal3S
* Phosphate-groups
  * i.e. Gal3P
* Nitrogen-groups
  * i.e. GalN or Gal3N
* Acid-groups
  * i.e. GalA or GalNAc or Gal2Ac or 2-O-Me-Gal
* Methyl-groups
  * i.e. Gal2Me or 2-O-Me-Gal
* Desoxygenation
  * i.e. 3dGal
  * This can be parsed but not converted into SMILES. Currently, it is just discarded.